@@ -2,7 +2,7 @@ package Plack::Middleware::DNSBL;
 use parent qw(Plack::Middleware);
 use strict; use warnings;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Carp ();
 use Plack::Util::Accessor qw(cache cache_time resolver blacklists blacklisted);
@@ -106,10 +106,6 @@ Plack::Middleware::DNSBL - An IPv4 DNS Blacklist middleware for Plack
 
 =head1 SYNOPSIS
 
-The Plack::Middleware::DNSBL middleware provides a simple yet customizable way
-of blocking ill-intentionated requests from reaching your main application by
-using an external blacklist.
-
   use Plack::Builder;
   use Plack::Middleware::DNSBL;
   
@@ -125,6 +121,12 @@ using an external blacklist.
       $app;
   }
 
+=head1 DESCRIPTION
+
+The Plack::Middleware::DNSBL middleware provides a simple yet customizable way
+of blocking ill-intentionated requests from reaching your main application by
+using an external blacklist.
+
 =head1 CONFIGURATIONS
 
 =over 4
@@ -220,10 +222,6 @@ A L<Net::DNS::Resolver> object. Defaults to C<< Net::DNS::Resolver->new >>.
 
 =back
 
-=head1 SEE ALSO
-
-L<Net::DNS::Resolver>
-
 =head1 WHITELISTING
 
 There's no build-in way of whitelisting IPs or certain paths, however this can
@@ -236,58 +234,20 @@ be quickly solved by using Plack::Builder's C<enable_if>:
       $app;
   };
 
+=head1 SEE ALSO
+
+L<Net::DNS::Resolver>
+
 =head1 AUTHOR
 
 Victor Franco, C<< <victorfrancovl at gmail.com> >>
 
 =head1 BUGS
 
-Please report any bugs or feature requests to C<bug-plack-middleware-dnsbl at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Plack-Middleware-DNSBL>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
-
 Patches welcome at L<https://www.github.com/vtfrvl/plack-middleware-dnsbl>
 
-=head1
-
-=head1 COPYRIGHT
-
-Copyright 2015 Victor Franco.
-
 =head1 LICENSE
 
-This program is free software; you can redistribute it and/or modify it
-under the terms of the the Artistic License (2.0). You may obtain a
-copy of the full license at:
+This library is free software; you can redistribute it and/or modify it under
+the same terms as Perl itself
 
-L<http://www.perlfoundation.org/artistic_license_2_0>
-
-Any use, modification, and distribution of the Standard or Modified
-Versions is governed by this Artistic License. By using, modifying or
-distributing the Package, you accept this license. Do not use, modify,
-or distribute the Package, if you do not accept this license.
-
-If your Modified Version has been derived from a Modified Version made
-by someone other than you, you are nevertheless required to ensure that
-your Modified Version complies with the requirements of this license.
-
-This license does not grant you the right to use any trademark, service
-mark, tradename, or logo of the Copyright Holder.
-
-This license includes the non-exclusive, worldwide, free-of-charge
-patent license to make, have made, use, offer to sell, sell, import and
-otherwise transfer the Package with respect to any patent claims
-licensable by the Copyright Holder that are necessarily infringed by the
-Package. If you institute patent litigation (including a cross-claim or
-counterclaim) against any party alleging that the Package constitutes
-direct or contributory patent infringement, then this Artistic License
-to you shall terminate on the date that such litigation is filed.
-
-Disclaimer of Warranty: THE PACKAGE IS PROVIDED BY THE COPYRIGHT HOLDER
-AND CONTRIBUTORS "AS IS' AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES.
-THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-PURPOSE, OR NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY
-YOUR LOCAL LAW. UNLESS REQUIRED BY LAW, NO COPYRIGHT HOLDER OR
-CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, OR
-CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE OF THE PACKAGE,
-EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
